@@ -105,7 +105,7 @@ class KubeModel(ABC):
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
         # TODO here the state loaded should be the averaged one not the saved from earlier
-        # right now, there is no averaging 
+
         # self._load_optimizer_state()
 
     def _load_optimizer_state(self):
@@ -132,42 +132,11 @@ class KubeModel(ABC):
         Saves the optimizer state to be loaded again in
         the following epochs
         """
-        #TODO: use file name {job_id}-opt.pkl instead
         self.logger.debug('saving optimizer state')
         with open('opt.pkl', 'wb') as f:
             pickle.dump(self.optimizer.state_dict(), f)
         print('saved state')
 
-    def _save_optimizer_redis(self):
-        """
-        Saves the optimizer to the redis
-        """
-        job_id = self.args._job_id
-        func_id = self.args._func_id
-
-        self.logger.debug("Saving optimizer to the database")
-
-        weight_key = f'{job_id}:optimizer:{func_id}' 
-        pickled_val  = pickle.dumps(self.optimizer.state_dict())
-        self._redis_client.set(weight_key, pickled_val)
-
-        self.logger.debug('Saved optimizer to the database')
-
-    def _load_optimizer_redis(self):
-        """
-        Checks for a previously saved state of the optimizer and loads it from redis
-        """
-
-        if self.epoch > 0:
-            job_id = self.args._job_id
-            func_id = self.args._func_id
-            weight_key = f'{job_id}:optimizer:{func_id}' 
-            pickled_val = self._redis_client.get(weight_key)
-            opt_states = pickle.loads(pickled_val)  
-            self.optimizer.load_state_dict(opt_states)
-
-
-
     def _get_logger(self):
         """
         Sets the current logger within the network according to the flask context
@@ -233,9 +202,10 @@ class KubeModel(ABC):
         Executed after the end of the training loop
         :return:
         """
-        pass
+        self.__save_model()
+
+        #pass
         # self._save_optimizer_state()
-        # TODO: delete optimizer file in the end of each job?
 
     def _on_iteration_start(self):
         """
@@ -246,18 +216,14 @@ class KubeModel(ABC):
         :return:
         """
         self.__load_model()
-        # not sure why we need to reset_optimizer state, instead, you might want to load the state if possible
         #self._reset_optimizer_state()
-        self._load_optimizer_redis()
-        
+
     def _on_iteration_end(self):
         """
         Called at the end of each iteration
         :return:
         """
         self.__save_model()
-        # you also need to save optimizer state
-        self._save_optimizer_redis()
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
         """
@@ -292,6 +258,7 @@ class KubeModel(ABC):
 
         :return: The loss of the epoch, as returned by the user function
         """
+
         self._on_train_start()
 
         # Determine the batches that we need to train on and the first subset id
@@ -508,4 +475,4 @@ class KubeModel(ABC):
         pass
 
     def infer(self, data: List[Any]) -> Union[torch.Tensor, np.ndarray, List[float]]:
-        pass
+        pass
\ No newline at end of file
